@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 #  A library that provides a Python interface to the Telegram Bot API
-#  Copyright (C) 2015-2022
+#  Copyright (C) 2015-2023
 #  Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 #  This program is free software: you can redistribute it and/or modify
@@ -17,10 +17,9 @@
 #  You should have received a copy of the GNU Lesser Public License
 #  along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains the CallbackDataCache class."""
-import logging
 import time
 from datetime import datetime
-from typing import TYPE_CHECKING, Dict, MutableMapping, Optional, Tuple, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, MutableMapping, Optional, Tuple, Union, cast
 from uuid import uuid4
 
 try:
@@ -42,7 +41,7 @@ if TYPE_CHECKING:
 
 class InvalidCallbackData(TelegramError):
     """
-    Raised when the received callback data has been tempered with or deleted from cache.
+    Raised when the received callback data has been tampered with or deleted from cache.
 
     Examples:
         :any:`Arbitrary Callback Data Bot <examples.arbitrarycallbackdatabot>`
@@ -62,12 +61,12 @@ class InvalidCallbackData(TelegramError):
 
     __slots__ = ("callback_data",)
 
-    def __init__(self, callback_data: str = None) -> None:
+    def __init__(self, callback_data: Optional[str] = None) -> None:
         super().__init__(
             "The object belonging to this callback_data was deleted or the callback_data was "
             "manipulated."
         )
-        self.callback_data = callback_data
+        self.callback_data: Optional[str] = callback_data
 
     def __reduce__(self) -> Tuple[type, Tuple[Optional[str]]]:  # type: ignore[override]
         return self.__class__, (self.callback_data,)
@@ -77,7 +76,10 @@ class _KeyboardData:
     __slots__ = ("keyboard_uuid", "button_data", "access_time")
 
     def __init__(
-        self, keyboard_uuid: str, access_time: float = None, button_data: Dict[str, object] = None
+        self,
+        keyboard_uuid: str,
+        access_time: Optional[float] = None,
+        button_data: Optional[Dict[str, object]] = None,
     ):
         self.keyboard_uuid = keyboard_uuid
         self.button_data = button_data or {}
@@ -111,20 +113,19 @@ class CallbackDataCache:
 
         .. code-block:: bash
 
-           pip install python-telegram-bot[callback-data]
+           pip install "python-telegram-bot[callback-data]"
 
     Examples:
         :any:`Arbitrary Callback Data Bot <examples.arbitrarycallbackdatabot>`
 
-    .. seealso:: :attr:`telegram.ext.ExtBot.callback_data_cache`,
-        :wiki:`Architecture Overview <Architecture>`,
+    .. seealso:: :wiki:`Architecture Overview <Architecture>`,
         :wiki:`Arbitrary callback_data <Arbitrary-callback_data>`
 
     .. versionadded:: 13.6
 
     .. versionchanged:: 20.0
         To use this class, PTB must be installed via
-        ``pip install python-telegram-bot[callback-data]``.
+        ``pip install "python-telegram-bot[callback-data]"``.
 
     Args:
         bot (:class:`telegram.ext.ExtBot`): The bot this cache is for.
@@ -141,24 +142,22 @@ class CallbackDataCache:
 
     """
 
-    __slots__ = ("bot", "_maxsize", "_keyboard_data", "_callback_queries", "logger")
+    __slots__ = ("bot", "_maxsize", "_keyboard_data", "_callback_queries")
 
     def __init__(
         self,
-        bot: "ExtBot",
+        bot: "ExtBot[Any]",
         maxsize: int = 1024,
-        persistent_data: CDCData = None,
+        persistent_data: Optional[CDCData] = None,
     ):
         if not CACHE_TOOLS_AVAILABLE:
             raise RuntimeError(
                 "To use `CallbackDataCache`, PTB must be installed via `pip install "
-                "python-telegram-bot[callback-data]`."
+                '"python-telegram-bot[callback-data]"`.'
             )
 
-        self.logger = logging.getLogger(__name__)
-
-        self.bot = bot
-        self._maxsize = maxsize
+        self.bot: ExtBot[Any] = bot
+        self._maxsize: int = maxsize
         self._keyboard_data: MutableMapping[str, _KeyboardData] = LRUCache(maxsize=maxsize)
         self._callback_queries: MutableMapping[str, str] = LRUCache(maxsize=maxsize)
 
@@ -423,7 +422,7 @@ class CallbackDataCache:
         except KeyError:
             return
 
-    def clear_callback_data(self, time_cutoff: Union[float, datetime] = None) -> None:
+    def clear_callback_data(self, time_cutoff: Optional[Union[float, datetime]] = None) -> None:
         """Clears the stored callback data.
 
         Args:
@@ -440,7 +439,9 @@ class CallbackDataCache:
         """Clears the stored callback query IDs."""
         self.__clear(self._callback_queries)
 
-    def __clear(self, mapping: MutableMapping, time_cutoff: Union[float, datetime] = None) -> None:
+    def __clear(
+        self, mapping: MutableMapping, time_cutoff: Optional[Union[float, datetime]] = None
+    ) -> None:
         if not time_cutoff:
             mapping.clear()
             return
